/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwizard.sip"
#include <qwizard.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractbutton.sip"
#include <qabstractbutton.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 27 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qpywidgets_qlist.sip"
#include <qwizard.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 171 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwizard.sip"
#include <qwizard.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 224 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 227 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 230 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 235 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 238 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 241 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 244 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 247 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 250 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 253 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 256 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 259 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 262 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 265 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"


class sipQWizard : public ::QWizard
{
public:
    sipQWizard(::QWidget*, ::Qt::WindowFlags);
    virtual ~sipQWizard();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void cleanupPage(int) SIP_OVERRIDE;
    void initializePage(int) SIP_OVERRIDE;
    int nextId() const SIP_OVERRIDE;
    bool validateCurrentPage() SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    int exec() SIP_OVERRIDE;
    void done(int) SIP_OVERRIDE;
    void accept() SIP_OVERRIDE;
    void reject() SIP_OVERRIDE;
    void open() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQWizard(const sipQWizard &);
    sipQWizard &operator = (const sipQWizard &);

    char sipPyMethods[55];
};

sipQWizard::sipQWizard(::QWidget*a0, ::Qt::WindowFlags a1): ::QWizard(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQWizard::~sipQWizard()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQWizard::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QWizard);

    return ::QWizard::metaObject();
}

int sipQWizard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QWizard::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QWizard, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQWizard::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QWizard, _clname, &sipCpp) ? sipCpp : ::QWizard::qt_metacast(_clname));
}

void sipQWizard::cleanupPage(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_cleanupPage);

    if (!sipMeth)
    {
        ::QWizard::cleanupPage(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::initializePage(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_initializePage);

    if (!sipMeth)
    {
        ::QWizard::initializePage(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQWizard::nextId() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_nextId);

    if (!sipMeth)
        return ::QWizard::nextId();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQWizard::validateCurrentPage()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_validateCurrentPage);

    if (!sipMeth)
        return ::QWizard::validateCurrentPage();

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQWizard::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QWizard::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainter* sipQWizard::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QWizard::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQWizard::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QWizard::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQWizard::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QWizard::hasHeightForWidth();

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQWizard::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QWizard::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQWizard::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QWizard::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QWizard::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QWizard::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QWizard::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QWizard::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QWizard::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QWizard::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QWizard::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QWizard::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QWizard::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QWizard::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QWizard::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QWizard::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QWizard::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QWizard::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QWizard::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QWizard::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QWizard::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QWizard::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QWizard::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QWizard::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QWizard::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QWizard::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QWizard::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QWizard::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QWizard::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QWizard::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQWizard::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[36]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QWizard::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQWizard::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QWizard::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQWizard::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QWizard::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQWizard::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QWizard::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQWizard::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[40]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QWizard::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPaintEngine* sipQWizard::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QWizard::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQWizard::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[42]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QWizard::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWizard::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QWizard::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWizard::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QWizard::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQWizard::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QWizard::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[46], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QWizard::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QWizard::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QWizard::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QWizard::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQWizard::exec()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[50], &sipPySelf, SIP_NULLPTR, sipName_exec);

    if (!sipMeth)
        return ::QWizard::exec();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQWizard::done(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[51], &sipPySelf, SIP_NULLPTR, sipName_done);

    if (!sipMeth)
    {
        ::QWizard::done(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWizard::accept()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[52], &sipPySelf, SIP_NULLPTR, sipName_accept);

    if (!sipMeth)
    {
        ::QWizard::accept();
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQWizard::reject()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[53], &sipPySelf, SIP_NULLPTR, sipName_reject);

    if (!sipMeth)
    {
        ::QWizard::reject();
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQWizard::open()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[54], &sipPySelf, SIP_NULLPTR, sipName_open);

    if (!sipMeth)
    {
        ::QWizard::open();
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QWizard_addPage, "addPage(self, page: QWizardPage|None) -> int");

extern "C" {static PyObject *meth_QWizard_addPage(PyObject *, PyObject *);}
static PyObject *meth_QWizard_addPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizardPage* a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizardPage, &a0))
        {
            int sipRes;

            sipRes = sipCpp->addPage(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_addPage, doc_QWizard_addPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setPage, "setPage(self, id: int, page: QWizardPage|None)");

extern "C" {static PyObject *meth_QWizard_setPage(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QWizardPage* a1;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QWizard, &sipCpp, &a0, sipType_QWizardPage, &a1))
        {
            sipCpp->setPage(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setPage, doc_QWizard_setPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_page, "page(self, id: int) -> QWizardPage|None");

extern "C" {static PyObject *meth_QWizard_page(PyObject *, PyObject *);}
static PyObject *meth_QWizard_page(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWizard, &sipCpp, &a0))
        {
            ::QWizardPage*sipRes;

            sipRes = sipCpp->page(a0);

            return sipConvertFromType(sipRes, sipType_QWizardPage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_page, doc_QWizard_page);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_hasVisitedPage, "hasVisitedPage(self, id: int) -> bool");

extern "C" {static PyObject *meth_QWizard_hasVisitedPage(PyObject *, PyObject *);}
static PyObject *meth_QWizard_hasVisitedPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWizard, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->hasVisitedPage(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_hasVisitedPage, doc_QWizard_hasVisitedPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_visitedIds, "visitedIds(self) -> list[int]");

extern "C" {static PyObject *meth_QWizard_visitedIds(PyObject *, PyObject *);}
static PyObject *meth_QWizard_visitedIds(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            ::QList<int>*sipRes;

            sipRes = new ::QList<int>(sipCpp->visitedIds());

            return sipConvertFromNewType(sipRes, sipType_QList_1800, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_visitedIds, doc_QWizard_visitedIds);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setStartId, "setStartId(self, id: int)");

extern "C" {static PyObject *meth_QWizard_setStartId(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setStartId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWizard, &sipCpp, &a0))
        {
            sipCpp->setStartId(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setStartId, doc_QWizard_setStartId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_startId, "startId(self) -> int");

extern "C" {static PyObject *meth_QWizard_startId(PyObject *, PyObject *);}
static PyObject *meth_QWizard_startId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->startId();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_startId, doc_QWizard_startId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_currentPage, "currentPage(self) -> QWizardPage|None");

extern "C" {static PyObject *meth_QWizard_currentPage(PyObject *, PyObject *);}
static PyObject *meth_QWizard_currentPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            ::QWizardPage*sipRes;

            sipRes = sipCpp->currentPage();

            return sipConvertFromType(sipRes, sipType_QWizardPage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_currentPage, doc_QWizard_currentPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_currentId, "currentId(self) -> int");

extern "C" {static PyObject *meth_QWizard_currentId(PyObject *, PyObject *);}
static PyObject *meth_QWizard_currentId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentId();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_currentId, doc_QWizard_currentId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_validateCurrentPage, "validateCurrentPage(self) -> bool");

extern "C" {static PyObject *meth_QWizard_validateCurrentPage(PyObject *, PyObject *);}
static PyObject *meth_QWizard_validateCurrentPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWizard::validateCurrentPage() : sipCpp->validateCurrentPage());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_validateCurrentPage, doc_QWizard_validateCurrentPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_nextId, "nextId(self) -> int");

extern "C" {static PyObject *meth_QWizard_nextId(PyObject *, PyObject *);}
static PyObject *meth_QWizard_nextId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWizard::nextId() : sipCpp->nextId());

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_nextId, doc_QWizard_nextId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setField, "setField(self, name: str|None, value: Any)");

extern "C" {static PyObject *meth_QWizard_setField(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setField(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QWizard, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setField(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setField, doc_QWizard_setField);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_field, "field(self, name: str|None) -> Any");

extern "C" {static PyObject *meth_QWizard_field(PyObject *, PyObject *);}
static PyObject *meth_QWizard_field(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWizard, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->field(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_field, doc_QWizard_field);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setWizardStyle, "setWizardStyle(self, style: QWizard.WizardStyle)");

extern "C" {static PyObject *meth_QWizard_setWizardStyle(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setWizardStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardStyle a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizard_WizardStyle, &a0))
        {
            sipCpp->setWizardStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setWizardStyle, doc_QWizard_setWizardStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_wizardStyle, "wizardStyle(self) -> QWizard.WizardStyle");

extern "C" {static PyObject *meth_QWizard_wizardStyle(PyObject *, PyObject *);}
static PyObject *meth_QWizard_wizardStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            ::QWizard::WizardStyle sipRes;

            sipRes = sipCpp->wizardStyle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QWizard_WizardStyle);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_wizardStyle, doc_QWizard_wizardStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setOption, "setOption(self, option: QWizard.WizardOption, on: bool = True)");

extern "C" {static PyObject *meth_QWizard_setOption(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWizard_setOption(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardOption a0;
        bool a1 = 1;
        ::QWizard *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_on,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizard_WizardOption, &a0, &a1))
        {
            sipCpp->setOption(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setOption, doc_QWizard_setOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_testOption, "testOption(self, option: QWizard.WizardOption) -> bool");

extern "C" {static PyObject *meth_QWizard_testOption(PyObject *, PyObject *);}
static PyObject *meth_QWizard_testOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardOption a0;
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizard_WizardOption, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->testOption(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_testOption, doc_QWizard_testOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setOptions, "setOptions(self, options: QWizard.WizardOption)");

extern "C" {static PyObject *meth_QWizard_setOptions(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardOptions* a0;
        int a0State = 0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWizard, &sipCpp, sipType_QFlags_0100QWizard_WizardOption, &a0, &a0State))
        {
            sipCpp->setOptions(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QWizard_WizardOption, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setOptions, doc_QWizard_setOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_options, "options(self) -> QWizard.WizardOption");

extern "C" {static PyObject *meth_QWizard_options(PyObject *, PyObject *);}
static PyObject *meth_QWizard_options(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            ::QWizard::WizardOptions*sipRes;

            sipRes = new ::QWizard::WizardOptions(sipCpp->options());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QWizard_WizardOption, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_options, doc_QWizard_options);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setButtonText, "setButtonText(self, which: QWizard.WizardButton, text: str|None)");

extern "C" {static PyObject *meth_QWizard_setButtonText(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setButtonText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardButton a0;
        const ::QString* a1;
        int a1State = 0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizard_WizardButton, &a0, sipType_QString, &a1, &a1State))
        {
            sipCpp->setButtonText(a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setButtonText, doc_QWizard_setButtonText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_buttonText, "buttonText(self, which: QWizard.WizardButton) -> str");

extern "C" {static PyObject *meth_QWizard_buttonText(PyObject *, PyObject *);}
static PyObject *meth_QWizard_buttonText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardButton a0;
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizard_WizardButton, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->buttonText(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_buttonText, doc_QWizard_buttonText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setButtonLayout, "setButtonLayout(self, layout: Iterable[QWizard.WizardButton])");

extern "C" {static PyObject *meth_QWizard_setButtonLayout(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setButtonLayout(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QList< ::QWizard::WizardButton>* a0;
        int a0State = 0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWizard, &sipCpp, sipType_QList_0100QWizard_WizardButton, &a0, &a0State))
        {
            sipCpp->setButtonLayout(*a0);
            sipReleaseType(const_cast< ::QList< ::QWizard::WizardButton> *>(a0), sipType_QList_0100QWizard_WizardButton, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setButtonLayout, doc_QWizard_setButtonLayout);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setButton, "setButton(self, which: QWizard.WizardButton, button: QAbstractButton|None)");

extern "C" {static PyObject *meth_QWizard_setButton(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setButton(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardButton a0;
        ::QAbstractButton* a1;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ:", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizard_WizardButton, &a0, sipType_QAbstractButton, &a1))
        {
            sipCpp->setButton(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setButton, doc_QWizard_setButton);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_button, "button(self, which: QWizard.WizardButton) -> QAbstractButton|None");

extern "C" {static PyObject *meth_QWizard_button(PyObject *, PyObject *);}
static PyObject *meth_QWizard_button(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardButton a0;
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizard_WizardButton, &a0))
        {
            ::QAbstractButton*sipRes;

            sipRes = sipCpp->button(a0);

            return sipConvertFromType(sipRes, sipType_QAbstractButton, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_button, doc_QWizard_button);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setTitleFormat, "setTitleFormat(self, format: Qt.TextFormat)");

extern "C" {static PyObject *meth_QWizard_setTitleFormat(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setTitleFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::TextFormat a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWizard, &sipCpp, sipType_Qt_TextFormat, &a0))
        {
            sipCpp->setTitleFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setTitleFormat, doc_QWizard_setTitleFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_titleFormat, "titleFormat(self) -> Qt.TextFormat");

extern "C" {static PyObject *meth_QWizard_titleFormat(PyObject *, PyObject *);}
static PyObject *meth_QWizard_titleFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            ::Qt::TextFormat sipRes;

            sipRes = sipCpp->titleFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_TextFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_titleFormat, doc_QWizard_titleFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setSubTitleFormat, "setSubTitleFormat(self, format: Qt.TextFormat)");

extern "C" {static PyObject *meth_QWizard_setSubTitleFormat(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setSubTitleFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::TextFormat a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWizard, &sipCpp, sipType_Qt_TextFormat, &a0))
        {
            sipCpp->setSubTitleFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setSubTitleFormat, doc_QWizard_setSubTitleFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_subTitleFormat, "subTitleFormat(self) -> Qt.TextFormat");

extern "C" {static PyObject *meth_QWizard_subTitleFormat(PyObject *, PyObject *);}
static PyObject *meth_QWizard_subTitleFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            ::Qt::TextFormat sipRes;

            sipRes = sipCpp->subTitleFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_TextFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_subTitleFormat, doc_QWizard_subTitleFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setPixmap, "setPixmap(self, which: QWizard.WizardPixmap, pixmap: QPixmap)");

extern "C" {static PyObject *meth_QWizard_setPixmap(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setPixmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardPixmap a0;
        const ::QPixmap* a1;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ9", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizard_WizardPixmap, &a0, sipType_QPixmap, &a1))
        {
            sipCpp->setPixmap(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setPixmap, doc_QWizard_setPixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_pixmap, "pixmap(self, which: QWizard.WizardPixmap) -> QPixmap");

extern "C" {static PyObject *meth_QWizard_pixmap(PyObject *, PyObject *);}
static PyObject *meth_QWizard_pixmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard::WizardPixmap a0;
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWizard_WizardPixmap, &a0))
        {
            ::QPixmap*sipRes;

            sipRes = new ::QPixmap(sipCpp->pixmap(a0));

            return sipConvertFromNewType(sipRes, sipType_QPixmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_pixmap, doc_QWizard_pixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setDefaultProperty, "setDefaultProperty(self, className: str, property: str, changedSignal: PYQT_SIGNAL)");

extern "C" {static PyObject *meth_QWizard_setDefaultProperty(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setDefaultProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const char* a0;
        PyObject *a0Keep;
        const char* a1;
        PyObject *a1Keep;
        PyObject * a2;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BAAAAP0", &sipSelf, sipType_QWizard, &sipCpp, &a0Keep, &a0, &a1Keep, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 119 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwizard.sip"
        QByteArray signal_signature;
        
        if ((sipError = pyqt6_qtwidgets_get_signal_signature(a2, 0, signal_signature)) == sipErrorNone)
        {
            sipCpp->setDefaultProperty(a0, a1, signal_signature.constData());
        }
        else if (sipError == sipErrorContinue)
        {
            sipError = sipBadCallableArg(2, a2);
        }
#line 2174 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQWizard.cpp"
            Py_DECREF(a0Keep);
            Py_DECREF(a1Keep);

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setDefaultProperty, doc_QWizard_setDefaultProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setVisible, "setVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QWizard_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWizard, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWizard::setVisible(a0) : sipCpp->setVisible(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setVisible, doc_QWizard_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QWizard_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QWizard_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QWizard::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_sizeHint, doc_QWizard_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_back, "back(self)");

extern "C" {static PyObject *meth_QWizard_back(PyObject *, PyObject *);}
static PyObject *meth_QWizard_back(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            sipCpp->back();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_back, doc_QWizard_back);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_next, "next(self)");

extern "C" {static PyObject *meth_QWizard_next(PyObject *, PyObject *);}
static PyObject *meth_QWizard_next(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            sipCpp->next();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_next, doc_QWizard_next);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_restart, "restart(self)");

extern "C" {static PyObject *meth_QWizard_restart(PyObject *, PyObject *);}
static PyObject *meth_QWizard_restart(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            sipCpp->restart();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_restart, doc_QWizard_restart);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_event, "event(self, event: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QWizard_event(PyObject *, PyObject *);}
static PyObject *meth_QWizard_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWizard, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWizard::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_event, doc_QWizard_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_resizeEvent, "resizeEvent(self, event: QResizeEvent|None)");

extern "C" {static PyObject *meth_QWizard_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QWizard_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWizard, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWizard::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_resizeEvent, doc_QWizard_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_paintEvent, "paintEvent(self, event: QPaintEvent|None)");

extern "C" {static PyObject *meth_QWizard_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QWizard_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWizard, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWizard::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_paintEvent, doc_QWizard_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_done, "done(self, result: int)");

extern "C" {static PyObject *meth_QWizard_done(PyObject *, PyObject *);}
static PyObject *meth_QWizard_done(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pi", &sipSelf, sipType_QWizard, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWizard::done(a0) : sipCpp->done(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_done, doc_QWizard_done);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_initializePage, "initializePage(self, id: int)");

extern "C" {static PyObject *meth_QWizard_initializePage(PyObject *, PyObject *);}
static PyObject *meth_QWizard_initializePage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pi", &sipSelf, sipType_QWizard, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWizard::initializePage(a0) : sipCpp->initializePage(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_initializePage, doc_QWizard_initializePage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_cleanupPage, "cleanupPage(self, id: int)");

extern "C" {static PyObject *meth_QWizard_cleanupPage(PyObject *, PyObject *);}
static PyObject *meth_QWizard_cleanupPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QWizard)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pi", &sipSelf, sipType_QWizard, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWizard::cleanupPage(a0) : sipCpp->cleanupPage(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_cleanupPage, doc_QWizard_cleanupPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_removePage, "removePage(self, id: int)");

extern "C" {static PyObject *meth_QWizard_removePage(PyObject *, PyObject *);}
static PyObject *meth_QWizard_removePage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWizard, &sipCpp, &a0))
        {
            sipCpp->removePage(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_removePage, doc_QWizard_removePage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_pageIds, "pageIds(self) -> list[int]");

extern "C" {static PyObject *meth_QWizard_pageIds(PyObject *, PyObject *);}
static PyObject *meth_QWizard_pageIds(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            ::QList<int>*sipRes;

            sipRes = new ::QList<int>(sipCpp->pageIds());

            return sipConvertFromNewType(sipRes, sipType_QList_1800, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_pageIds, doc_QWizard_pageIds);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setSideWidget, "setSideWidget(self, widget: QWidget|None)");

extern "C" {static PyObject *meth_QWizard_setSideWidget(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setSideWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QWizard, &sipCpp, sipType_QWidget, &a0))
        {
            sipCpp->setSideWidget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setSideWidget, doc_QWizard_setSideWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_sideWidget, "sideWidget(self) -> QWidget|None");

extern "C" {static PyObject *meth_QWizard_sideWidget(PyObject *, PyObject *);}
static PyObject *meth_QWizard_sideWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWizard, &sipCpp))
        {
            ::QWidget*sipRes;

            sipRes = sipCpp->sideWidget();

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_sideWidget, doc_QWizard_sideWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWizard_setCurrentId, "setCurrentId(self, id: int)");

extern "C" {static PyObject *meth_QWizard_setCurrentId(PyObject *, PyObject *);}
static PyObject *meth_QWizard_setCurrentId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QWizard *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWizard, &sipCpp, &a0))
        {
            sipCpp->setCurrentId(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWizard, sipName_setCurrentId, doc_QWizard_setCurrentId);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWizard(void *, const sipTypeDef *);}
static void *cast_QWizard(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWizard *sipCpp = reinterpret_cast< ::QWizard *>(sipCppV);

    if (targetType == sipType_QWizard)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QDialog)->ctd_cast(static_cast< ::QDialog *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWizard(void *, int);}
static void release_QWizard(void *sipCppV, int)
{
    ::QWizard *sipCpp = reinterpret_cast< ::QWizard *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QWizard(Py_ssize_t);}
static void *array_QWizard(Py_ssize_t sipNrElem)
{
    return new ::QWizard[sipNrElem];
}


extern "C" {static void array_delete_QWizard(void *);}
static void array_delete_QWizard(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWizard *>(sipCpp);
}


extern "C" {static void dealloc_QWizard(sipSimpleWrapper *);}
static void dealloc_QWizard(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQWizard *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWizard(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QWizard(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWizard(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQWizard *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;
        ::Qt::WindowFlags a1def = Qt::WindowFlags();
        ::Qt::WindowFlags* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JHJ1", sipType_QWidget, &a0, sipOwner, sipType_QFlags_0100Qt_WindowType, &a1, &a1State))
        {
            sipCpp = new sipQWizard(a0, *a1);
            sipReleaseType(a1, sipType_QFlags_0100Qt_WindowType, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWizard[] = {{51, 255, 1}};


static PyMethodDef methods_QWizard[] = {
    {sipName_addPage, meth_QWizard_addPage, METH_VARARGS, doc_QWizard_addPage},
    {sipName_back, meth_QWizard_back, METH_VARARGS, doc_QWizard_back},
    {sipName_button, meth_QWizard_button, METH_VARARGS, doc_QWizard_button},
    {sipName_buttonText, meth_QWizard_buttonText, METH_VARARGS, doc_QWizard_buttonText},
    {sipName_cleanupPage, meth_QWizard_cleanupPage, METH_VARARGS, doc_QWizard_cleanupPage},
    {sipName_currentId, meth_QWizard_currentId, METH_VARARGS, doc_QWizard_currentId},
    {sipName_currentPage, meth_QWizard_currentPage, METH_VARARGS, doc_QWizard_currentPage},
    {sipName_done, meth_QWizard_done, METH_VARARGS, doc_QWizard_done},
    {sipName_event, meth_QWizard_event, METH_VARARGS, doc_QWizard_event},
    {sipName_field, meth_QWizard_field, METH_VARARGS, doc_QWizard_field},
    {sipName_hasVisitedPage, meth_QWizard_hasVisitedPage, METH_VARARGS, doc_QWizard_hasVisitedPage},
    {sipName_initializePage, meth_QWizard_initializePage, METH_VARARGS, doc_QWizard_initializePage},
    {sipName_next, meth_QWizard_next, METH_VARARGS, doc_QWizard_next},
    {sipName_nextId, meth_QWizard_nextId, METH_VARARGS, doc_QWizard_nextId},
    {sipName_options, meth_QWizard_options, METH_VARARGS, doc_QWizard_options},
    {sipName_page, meth_QWizard_page, METH_VARARGS, doc_QWizard_page},
    {sipName_pageIds, meth_QWizard_pageIds, METH_VARARGS, doc_QWizard_pageIds},
    {sipName_paintEvent, meth_QWizard_paintEvent, METH_VARARGS, doc_QWizard_paintEvent},
    {sipName_pixmap, meth_QWizard_pixmap, METH_VARARGS, doc_QWizard_pixmap},
    {sipName_removePage, meth_QWizard_removePage, METH_VARARGS, doc_QWizard_removePage},
    {sipName_resizeEvent, meth_QWizard_resizeEvent, METH_VARARGS, doc_QWizard_resizeEvent},
    {sipName_restart, meth_QWizard_restart, METH_VARARGS, doc_QWizard_restart},
    {sipName_setButton, meth_QWizard_setButton, METH_VARARGS, doc_QWizard_setButton},
    {sipName_setButtonLayout, meth_QWizard_setButtonLayout, METH_VARARGS, doc_QWizard_setButtonLayout},
    {sipName_setButtonText, meth_QWizard_setButtonText, METH_VARARGS, doc_QWizard_setButtonText},
    {sipName_setCurrentId, meth_QWizard_setCurrentId, METH_VARARGS, doc_QWizard_setCurrentId},
    {sipName_setDefaultProperty, meth_QWizard_setDefaultProperty, METH_VARARGS, doc_QWizard_setDefaultProperty},
    {sipName_setField, meth_QWizard_setField, METH_VARARGS, doc_QWizard_setField},
    {sipName_setOption, SIP_MLMETH_CAST(meth_QWizard_setOption), METH_VARARGS|METH_KEYWORDS, doc_QWizard_setOption},
    {sipName_setOptions, meth_QWizard_setOptions, METH_VARARGS, doc_QWizard_setOptions},
    {sipName_setPage, meth_QWizard_setPage, METH_VARARGS, doc_QWizard_setPage},
    {sipName_setPixmap, meth_QWizard_setPixmap, METH_VARARGS, doc_QWizard_setPixmap},
    {sipName_setSideWidget, meth_QWizard_setSideWidget, METH_VARARGS, doc_QWizard_setSideWidget},
    {sipName_setStartId, meth_QWizard_setStartId, METH_VARARGS, doc_QWizard_setStartId},
    {sipName_setSubTitleFormat, meth_QWizard_setSubTitleFormat, METH_VARARGS, doc_QWizard_setSubTitleFormat},
    {sipName_setTitleFormat, meth_QWizard_setTitleFormat, METH_VARARGS, doc_QWizard_setTitleFormat},
    {sipName_setVisible, meth_QWizard_setVisible, METH_VARARGS, doc_QWizard_setVisible},
    {sipName_setWizardStyle, meth_QWizard_setWizardStyle, METH_VARARGS, doc_QWizard_setWizardStyle},
    {sipName_sideWidget, meth_QWizard_sideWidget, METH_VARARGS, doc_QWizard_sideWidget},
    {sipName_sizeHint, meth_QWizard_sizeHint, METH_VARARGS, doc_QWizard_sizeHint},
    {sipName_startId, meth_QWizard_startId, METH_VARARGS, doc_QWizard_startId},
    {sipName_subTitleFormat, meth_QWizard_subTitleFormat, METH_VARARGS, doc_QWizard_subTitleFormat},
    {sipName_testOption, meth_QWizard_testOption, METH_VARARGS, doc_QWizard_testOption},
    {sipName_titleFormat, meth_QWizard_titleFormat, METH_VARARGS, doc_QWizard_titleFormat},
    {sipName_validateCurrentPage, meth_QWizard_validateCurrentPage, METH_VARARGS, doc_QWizard_validateCurrentPage},
    {sipName_visitedIds, meth_QWizard_visitedIds, METH_VARARGS, doc_QWizard_visitedIds},
    {sipName_wizardStyle, meth_QWizard_wizardStyle, METH_VARARGS, doc_QWizard_wizardStyle}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QWizard[] = {
    {sipName_BackButton, static_cast<int>(::QWizard::BackButton)},
    {sipName_NextButton, static_cast<int>(::QWizard::NextButton)},
    {sipName_CommitButton, static_cast<int>(::QWizard::CommitButton)},
    {sipName_FinishButton, static_cast<int>(::QWizard::FinishButton)},
    {sipName_CancelButton, static_cast<int>(::QWizard::CancelButton)},
    {sipName_HelpButton, static_cast<int>(::QWizard::HelpButton)},
    {sipName_CustomButton1, static_cast<int>(::QWizard::CustomButton1)},
    {sipName_CustomButton2, static_cast<int>(::QWizard::CustomButton2)},
    {sipName_CustomButton3, static_cast<int>(::QWizard::CustomButton3)},
    {sipName_Stretch, static_cast<int>(::QWizard::Stretch)},
    {sipName_IndependentPages, static_cast<int>(::QWizard::IndependentPages)},
    {sipName_IgnoreSubTitles, static_cast<int>(::QWizard::IgnoreSubTitles)},
    {sipName_ExtendedWatermarkPixmap, static_cast<int>(::QWizard::ExtendedWatermarkPixmap)},
    {sipName_NoDefaultButton, static_cast<int>(::QWizard::NoDefaultButton)},
    {sipName_NoBackButtonOnStartPage, static_cast<int>(::QWizard::NoBackButtonOnStartPage)},
    {sipName_NoBackButtonOnLastPage, static_cast<int>(::QWizard::NoBackButtonOnLastPage)},
    {sipName_DisabledBackButtonOnLastPage, static_cast<int>(::QWizard::DisabledBackButtonOnLastPage)},
    {sipName_HaveNextButtonOnLastPage, static_cast<int>(::QWizard::HaveNextButtonOnLastPage)},
    {sipName_HaveFinishButtonOnEarlyPages, static_cast<int>(::QWizard::HaveFinishButtonOnEarlyPages)},
    {sipName_NoCancelButton, static_cast<int>(::QWizard::NoCancelButton)},
    {sipName_CancelButtonOnLeft, static_cast<int>(::QWizard::CancelButtonOnLeft)},
    {sipName_HaveHelpButton, static_cast<int>(::QWizard::HaveHelpButton)},
    {sipName_HelpButtonOnRight, static_cast<int>(::QWizard::HelpButtonOnRight)},
    {sipName_HaveCustomButton1, static_cast<int>(::QWizard::HaveCustomButton1)},
    {sipName_HaveCustomButton2, static_cast<int>(::QWizard::HaveCustomButton2)},
    {sipName_HaveCustomButton3, static_cast<int>(::QWizard::HaveCustomButton3)},
    {sipName_NoCancelButtonOnLastPage, static_cast<int>(::QWizard::NoCancelButtonOnLastPage)},
    {sipName_StretchBanner, static_cast<int>(::QWizard::StretchBanner)},
    {sipName_WatermarkPixmap, static_cast<int>(::QWizard::WatermarkPixmap)},
    {sipName_LogoPixmap, static_cast<int>(::QWizard::LogoPixmap)},
    {sipName_BannerPixmap, static_cast<int>(::QWizard::BannerPixmap)},
    {sipName_BackgroundPixmap, static_cast<int>(::QWizard::BackgroundPixmap)},
    {sipName_ClassicStyle, static_cast<int>(::QWizard::ClassicStyle)},
    {sipName_ModernStyle, static_cast<int>(::QWizard::ModernStyle)},
    {sipName_MacStyle, static_cast<int>(::QWizard::MacStyle)},
    {sipName_AeroStyle, static_cast<int>(::QWizard::AeroStyle)},
    {0, 0}
};

PyDoc_STRVAR(doc_QWizard, "\1QWizard(parent: QWidget|None = None, flags: Qt.WindowType = Qt.WindowFlags())");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QWizard[] = {
    {"pageRemoved(int)", "\1pageRemoved(self, id: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"pageAdded(int)", "\1pageAdded(self, id: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"customButtonClicked(int)", "\1customButtonClicked(self, which: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"helpRequested()", "\1helpRequested(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentIdChanged(int)", "\1currentIdChanged(self, id: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QWizard = {
    &::QWizard::staticMetaObject,
    signals_QWizard,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QWizard = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWizard,
        SIP_NULLPTR,
        &plugin_QWizard,
    },
    {
        sipNameNr_QWizard,
        {0, 0, 1},
        47, methods_QWizard,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QWizard, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWizard,
    -1,
    -1,
    supers_QWizard,
    SIP_NULLPTR,
    init_type_QWizard,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWizard,
    SIP_NULLPTR,
    array_QWizard,
    SIP_NULLPTR,
    release_QWizard,
    cast_QWizard,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWizard,
    sizeof (::QWizard),
};
